<?php

/**
 * @package Tipzty
 *
 * Plugin Name: Tipzty
 * Plugin URI: https://tipzty.com
 * Description: Sincroniza las reseñas de tus productos con <strong>tipzty</strong>.
 * Version: 1.2.1
 * Author: Ricardo Moreno
 * Author URI: https://github.com/rich-97
 * Text Domain: Tipzty
 */

if (!function_exists("tipzty_activate")) {
  function tipzty_activate()
  {
  }
}

if (!function_exists("tipzty_deactivate")) {
  function tipzty_deactivate()
  {
    flush_rewrite_rules();
  }
}

register_activation_hook(__FILE__, 'tipzty_activate');
register_deactivation_hook(__FILE__, 'tipzty_deactivate');

if (!function_exists("tipzty_create_menu")) {
  function tipzty_create_menu()
  {
    add_menu_page(
      'Tipzty',
      'Tipzty',
      'manage_options',
      plugin_dir_path(__FILE__) . 'admin/dashboard.php',
      null,
      plugin_dir_url(__FILE__) . 'admin/img/icon.png',
      null
    );
  }
}

if (!function_exists("tipzty_admin_enqueue_scripts")) {
  function tipzty_admin_enqueue_scripts()
  {
    wp_enqueue_style('bootstrap_css', plugins_url('admin/bootstrap/css/bootstrap.min.css', __FILE__));
    wp_enqueue_script('bootstrap_js', plugins_url('admin/bootstrap/js/bootstrap.min.js', __FILE__), array('jquery'));
    wp_enqueue_style('event_css', plugins_url('client/css/style.css', __FILE__));
  }
}

if (!function_exists("tipzty_client_enqueue_scripts")) {
  function tipzty_client_enqueue_scripts()
  {
    wp_enqueue_style('event_css', plugins_url('client/css/style.css', __FILE__));
    wp_enqueue_script('client_js', plugins_url('client/js/main.js', __FILE__), array('jquery'));
  }
}

if (!function_exists("tipzty_get_token")) {
  function tipzty_get_token()
  {
    global $wpdb;

    $token = '';
    $query = "SELECT option_value FROM `wp_options` WHERE option_name = 'xTipztyToken'";
    $result = $wpdb->get_results($query, ARRAY_A);

    if (!empty($result)) {
      $token = $result[0]['option_value'];
    }

    return $token;
  }
}

if (!function_exists("tipzty_add_token_info")) {
  function tipzty_add_token_info()
  {
    $token = tipzty_get_token();

    echo "
      <script>
        localStorage.setItem('@token_tipzty_plugin', '" . $token . "');
      </script>
    ";
  }
}

if (!function_exists("tipzty_add_product_widget")) {
  function tipzty_add_product_widget()
  {
    global $product;

    echo "
      <script>
        localStorage.setItem('@product', JSON.stringify(" . $product . "));
      </script>
    ";
?>
    <div class="t-widget">
      <div class="t-block">
        <img class="t-logo animate" src="<?php echo plugins_url('admin/img/btn.png', __FILE__); ?>" onClick="toggleWidget(false)" />
      </div>
      <div class="t-review">
        <iframe class="t-iframe" src="" frameborder="0" allowfullscreen></iframe>
      </div>
    </div>
  <?php
    wp_enqueue_script('product_js', plugins_url('client/js/product.js', __FILE__), array('jquery'));
  }
}

if (!function_exists("tipzty_add_home_widget")) {
  function tipzty_add_home_widget()
  {
  ?>
    <div class="t-home-widget">
      <div class="t-block">
        <img class="t-logo animate" src="<?php echo plugins_url('admin/img/live.png', __FILE__); ?>" onClick="toggleWidget(true)" />
      </div>
      <div class="t-review">
        <iframe class="t-iframe" src="" frameborder="0" allowfullscreen></iframe>
      </div>
    </div>
  <?php
    wp_enqueue_script('home_js', plugins_url('client/js/home.js', __FILE__), array('jquery'));
  }
}

if (!function_exists("tipzty_wc_multiple_products_to_cart")) {
  function tipzty_wc_multiple_products_to_cart()
  {
    $query_ids = sanitize_text_field($_REQUEST['t-add-to-cart']);
    $is_valid = preg_match("/^[0-9]+$/", str_replace(",", "", $query_ids));

    if (!$is_valid) return;

    if (!class_exists('WC_Form_Handler') || empty($query_ids) || $query_ids === "" || false === strpos($query_ids, ',')) {
      return;
    }

    WC()->cart->empty_cart();

    $products = explode(',', $query_ids);

    foreach ($products as $product) {
      $parts = explode(":", $product);
      $product_id = $parts[0];
      $quantity = $parts[1];
      $variation_id = null;

      if (count($parts) > 2) {
        $variation_id = $parts[2];
      }

      $product_cart_id = WC()->cart->generate_cart_id($product_id);

      if (!WC()->cart->find_product_in_cart($product_cart_id)) {
        WC()->cart->add_to_cart($product_id, $quantity, $variation_id);
      }
    }
  }
}

if (!function_exists('tipzty_page_shortcode_reviews')) {
  function tipzty_page_shortcode_reviews()
  {
    $token = tipzty_get_token();
    $args = array(
      "method" => "GET",
      "headers" => array(
        "x-tipzty-key" => $token
      ),
    );
    $url = "https://go.tipzty.com/api/brand";
    $response = wp_remote_request($url, $args);
    $iframe_src = "https://tipz.tv";

    if ($response["response"]["code"] == 200) {
      $body = json_decode(wp_remote_retrieve_body($response));

      if (property_exists($body, "full_name")) {
        $full_name = $body->full_name;
        $full_name = strtolower($full_name);
        $full_name = str_replace(" ", "", $full_name);

        $iframe_src = "https://tipz.tv/reviews/$full_name?mode=widget&from=page";
      }
    }
  ?>
    <iframe class="t-shortcode-iframe-reviews" src="<?= $iframe_src ?>" frameborder="0" allowfullscreen></iframe>
<?php
  }
}

add_action('wp_loaded', 'tipzty_wc_multiple_products_to_cart', 15);
add_action('wp_footer', 'tipzty_add_token_info', 15);
add_action('wp_footer', 'tipzty_add_home_widget', 15);
add_action('wp_footer', 'tipzty_add_product_widget', 15);
add_filter('wc_add_to_cart_message_html', '__return_false');
add_action('admin_menu', 'tipzty_create_menu');

add_shortcode('tipzty_page_reviews', 'tipzty_page_shortcode_reviews');

// Admin scripts
add_action('admin_enqueue_scripts', 'tipzty_admin_enqueue_scripts');

// Client scripts
add_action('wp_enqueue_scripts', 'tipzty_client_enqueue_scripts');
